' ========================================================================================
' GdipGetLineBlend
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

%IDC_GRAPHIC = 101

' ========================================================================================
' The following example creates a linear gradient brush, sets its blend, and uses the
' brush to fill a rectangle. The code then gets the blend. The blend factors and positions
' can then be inspected or used in some way.
' ========================================================================================
SUB GDIP_GetLineBlend (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pLinBrush AS DWORD
   LOCAL colorRed AS DWORD
   LOCAL colorBlue AS DWORD
   LOCAL blendCount AS LONG
   LOCAL pt1 AS POINTF
   LOCAL pt2 AS POINTF
   LOCAL i AS LONG
   DIM   fac(3) AS SINGLE
   DIM   pos(3) AS SINGLE
   DIM   factors(0) AS SINGLE
   DIM   positions(0) AS SINGLE

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create a linear gradient brush, and set its blend.
   fac(0) = 0.0! : fac(1) = 0.4! : fac(2) = 0.6! : fac(3) = 1.0!
   pos(0) = 0.0! : pos(1) = 0.2! : pos(2) = 0.8! : pos(3) = 1.0!

   pt1.x = 0 : pt1.y = 0 : pt2.x = 100 : pt2.y = 0
   colorRed = GDIP_ARGB(255, 255, 0, 0)
   colorBlue = GDIP_ARGB(255, 0, 0, 255)
   hStatus = GdipCreateLineBrush(pt1, pt2, colorRed, colorBlue, %WrapModeTile, pLinBrush)

   hStatus = GdipSetLineBlend(pLinBrush, fac(0), pos(0), 4)

   ' // Use the linear gradient brush to fill a rectangle.
   hStatus = GdipFillRectangle(pGraphics, pLinBrush, 0, 0, 100, 50)

   ' // Obtain information about the linear gradient brush.
   hStatus = GdipGetLineBlendCount(pLinBrush, blendCount)
   IF blendCount THEN
      REDIM factors(blendCount-1)
      REDIM positions(blendCount-1)
      hStatus = GdipGetLineBlend(pLinBrush, factors(0), positions(0), blendCount)
      FOR i = 0 TO blendCount
         OutputDebugString "factor " & FORMAT$(i) & " =" & STR$(factors(i))
         OutputDebugString "position " & FORMAT$(i) & " =" & STR$(positions(i))
      NEXT
   END IF

   ' // Cleanup
   IF pLinBrush THEN GdipDeleteBrush(pLinBrush)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL hdc AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   ' Create a new dialog
   DIALOG NEW PIXELS, 0, "GdipGetLineBlend", , , 400, 250, %WS_SYSMENU TO hDlg

   ' Add a graphic control
   CONTROL ADD GRAPHIC, hDlg, %IDC_GRAPHIC,"", 0, 0, 400, 250
   ' Select the drawing target
   GRAPHIC ATTACH hDlg, %IDC_GRAPHIC
   ' Set the foreground and background color
   GRAPHIC COLOR %BLACK, %WHITE
   ' Clear the entire selected graphic window
   GRAPHIC CLEAR
   ' Retrieve the handle of the device context
   GRAPHIC GET DC TO hdc
   ' Draw the graphics
   GDIP_GetLineBlend hdc

   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

   END SELECT

END FUNCTION
' ========================================================================================
